#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-cipher-types
version:              0.0.9
visibility:           public
id:                   crypto-cipher-types-0.0.9-LQo54bzmotf2im7aqpU2MN
key:                  crypto-cipher-types-0.0.9-LQo54bzmotf2im7aqpU2MN
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-crypto-cipher
synopsis:             Generic cryptography cipher types
description:          Generic cryptography cipher types
category:             Cryptography
abi:                  ab50fbc2a4c7b2496a4ccd33a92f9ca6
exposed:              True
exposed-modules:      Crypto.Cipher.Types Crypto.Cipher.Types.Unsafe
hidden-modules:
    Crypto.Cipher.Types.GF Crypto.Cipher.Types.Block
    Crypto.Cipher.Types.BlockIO Crypto.Cipher.Types.Stream
    Crypto.Cipher.Types.OfIO Crypto.Cipher.Types.AEAD
    Crypto.Cipher.Types.Base Crypto.Cipher.Types.Utils

import-dirs:          /usr/lib/ghc-8.10.5/site-local/crypto-cipher-types-0.0.9
library-dirs:         /usr/lib/ghc-8.10.5/site-local/crypto-cipher-types-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-cipher-types
hs-libraries:         HScrypto-cipher-types-0.0.9-LQo54bzmotf2im7aqpU2MN
depends:
    base-4.14.2.0 byteable-0.1.1-Gf4TH6XbSdI4yHpNVK8xgD
    bytestring-0.10.12.0 securemem-0.1.10-BEeIFImmh46Qes0xw1pUh

haddock-interfaces:
    /usr/share/doc/haskell-crypto-cipher-types/html/crypto-cipher-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-cipher-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

